@@ -4,4 +4,5 @@
 # date: 2023/3/27
 
 
-from dtparser import parse
+from .dtparser import parse
+from .dtparser import check
